#!/usr/bin/env python
# -*- encoding: utf-8 -*-
'''
@File    :   卡证多轮对话模板.py
@Time    :   2024/10/21 17:22:26
@Author  :   moyan 
@Contact :   ice_moyan@163.com
'''
import os
import random


# 预定义的查询和响应列表
birthcer_queries_responses = {
    '新生儿姓名': {
        'queries': [
            "这张出生证上的新生儿叫什么名字？",
            "能告诉我出生证上的新生儿姓名吗？",
            "出生证上新生儿的名字是什么？",
            "请提取出生证上的新生儿姓名。",
            "出生证上的宝宝叫什么名字？",
            "新生儿的名字写在出生证上是怎样的？",
            "能帮我确认一下出生证上的新生儿姓名吗？",
            "出生证上的新生儿全名是什么？",
            "出生证上新生儿的完整姓名是什么？",
            "请核对一下出生证上的新生儿姓名。"
        ],
        'responses': [
            "出生证上的新生儿姓名是{}。",
            "新生儿的姓名是{}。",
            "新生儿的名字是{}。",
            "出生证上的新生儿姓名是{}。",
            "出生证上的宝宝姓名是{}。",
            "新生儿的名字在出生证上是{}。",
            "出生证上的新生儿姓名是{}。",
            "新生儿的全名是{}。",
            "新生儿的完整姓名是{}。",
            "出生证上的新生儿姓名是{}。",
            "{}"
        ]
    },
    '新生儿出生孕周': {
        'queries': [
            "出生证上记录的新生儿出生孕周是多少？",
            "新生儿是在第几周出生的？",
            "请提供出生证上的新生儿出生孕周。",
            "新生儿出生时的孕周数是多少？",
            "出生证上新生儿的孕周数是多少？",
            "新生儿的出生孕周是多少？",
            "能告诉我出生证上的新生儿出生孕周吗？",
            "新生儿的出生是在第几周？",
            "请核对一下出生证上的新生儿出生孕周。",
        ],
        'responses': [
            "出生证上记录的新生儿出生孕周是{}。",
            "新生儿是在第{}周出生的。",
            "出生证上的新生儿出生孕周是{}。",
            "新生儿出生时的孕周数是{}。",
            "出生证上新生儿的孕周数是{}。",
            "新生儿的出生孕周是{}。",
            "新生儿的出生是在第{}周。",
            "{}"
        ]
    },
    '新生儿出生体重': {
        'queries': [
            "出生证上新生儿的出生体重是多少？",
            "新生儿出生时的体重是多少？",
            "请提供出生证上的新生儿出生体重。",
            "出生证上新生儿的体重是多少？",
            "新生儿的出生体重是多少？",
            "能告诉我出生证上的新生儿出生体重吗？",
            "新生儿出生时有多重？",
            "请核对一下出生证上的新生儿出生体重。",
            "出生证上新生儿的出生体重是多少克？",
            "新生儿出生时的体重是多少克？"
        ],
        'responses': [
            "出生证上新生儿的出生体重是{}克。",
            "新生儿出生时的体重是{}克。",
            "出生证上的新生儿出生体重是{}克。",
            "出生证上新生儿的体重是{}克。",
            "新生儿的出生体重是{}克。",
            "新生儿出生时有{}克。",
            "{}"
        ]
    },
    '新生儿母亲姓名': {
        'queries': [
            "出生证上新生儿的母亲叫什么名字？",
            "能告诉我出生证上新生儿母亲的姓名吗？",
            "出生证上新生儿母亲的名字是什么？",
            "请提供出生证上的新生儿母亲姓名。",
            "出生证上新生儿的母亲叫什么？",
            "新生儿的母亲在出生证上的名字是什么？",
            "能帮忙确认一下出生证上的新生儿母亲姓名吗？",
            "出生证上新生儿母亲的全名是什么？",
            "出生证上新生儿母亲的完整姓名是什么？",
            "请核对一下出生证上的新生儿母亲姓名。"
        ],
        'responses': [
            "出生证上新生儿的母亲姓名是{}。",
            "新生儿母亲的姓名是{}。",
            "新生儿母亲的名字是{}。",
            "出生证上的新生儿母亲姓名是{}。",
            "出生证上新生儿的母亲叫{}。",
            "新生儿的母亲在出生证上的名字是{}。",
            "新生儿母亲的全名是{}。",
            "新生儿母亲的完整姓名是{}。",
            "{}"
        ]
    },
    '新生儿母亲身份证号码': {
        'queries': [
            "出生证上新生儿母亲的身份证号码是多少？",
            "能告诉我出生证上新生儿母亲的身份证号码吗？",
            "出生证上新生儿母亲的身份证号是什么？",
            "请提供出生证上的新生儿母亲身份证号码。",
            "新生儿母亲的身份证号码写在出生证上是怎样的？",
            "能帮忙确认一下出生证上的新生儿母亲身份证号码吗？",
            "出生证上新生儿母亲的完整身份证号码是什么？",
            "请核对一下出生证上的新生儿母亲身份证号码。",
        ],
        'responses': [
            "出生证上新生儿母亲的身份证号码是{}。",
            "新生儿母亲的身份证号码是{}。",
            "出生证上新生儿母亲的身份证号是{}。",
            "出生证上的新生儿母亲身份证号码是{}。",
            "新生儿母亲的身份证号码在出生证上是{}。",
            "新生儿母亲的完整身份证号码是{}。",
            "新生儿母亲的身份证号码是18位，具体号码是{}。",
            "{}"
        ]
    },
    '新生儿父亲姓名': {
        'queries': [
            "出生证上新生儿的父亲叫什么名字？",
            "能告诉我出生证上新生儿父亲的姓名吗？",
            "出生证上新生儿父亲的名字是什么？",
            "请提供出生证上的新生儿父亲姓名。",
            "出生证上新生儿的父亲叫什么？",
            "新生儿的父亲在出生证上的名字是什么？",
            "能帮忙确认一下出生证上的新生儿父亲姓名吗？",
            "出生证上新生儿父亲的全名是什么？",
            "出生证上新生儿父亲的完整姓名是什么？",
            "请核对一下出生证上的新生儿父亲姓名。"
        ],
        'responses': [
            "出生证上新生儿的父亲姓名是{}。",
            "新生儿父亲的姓名是{}。",
            "出生证上的新生儿父亲姓名是{}。",
            "出生证上新生儿的父亲叫{}。",
            "新生儿的父亲在出生证上的名字是{}。",
            "新生儿父亲的全名是{}。",
            "新生儿父亲的完整姓名是{}。",
            "{}"
        ]
    },
    '新生儿父亲身份证号码': {
        'queries': [
            "出生证上新生儿父亲的身份证号码是多少？",
            "能告诉我出生证上新生儿父亲的身份证号码吗？",
            "出生证上新生儿父亲的身份证号是什么？",
            "请提供出生证上的新生儿父亲身份证号码。",
            "新生儿父亲的身份证号码写在出生证上是怎样的？",
            "能帮忙确认一下出生证上的新生儿父亲身份证号码吗？",
            "出生证上新生儿父亲的完整身份证号码是什么？",
            "请核对一下出生证上的新生儿父亲身份证号码。",
        ],
        'responses': [
            "出生证上新生儿父亲的身份证号码是{}。",
            "新生儿父亲的身份证号码是{}。",
            "出生证上新生儿父亲的身份证号是{}。",
            "出生证上的新生儿父亲身份证号码是{}。",
            "新生儿父亲的身份证号码在出生证上是{}。",
            "新生儿父亲的完整身份证号码是{}。",
            "新生儿父亲的身份证号码是18位，具体号码是{}。",
            "{}"
        ]
    },
    '出生证编号': {
        'queries': [
            "这张出生证的编号是多少？",
            "能告诉我这张出生证的编号吗？",
            "出生证上的编号是多少？",
            "请提供这张出生证的编号。",
            "能帮忙确认一下这张出生证的编号吗？",
            "出生证上的完整编号是什么？",
            "请核对一下这张出生证的编号。",
        ],
        'responses': [
            "这张出生证的编号是{}。",
            "出生证上的编号是{}。",
            "出生证的编号通常写在证件的右下角，编号是{}。",
            "出生证上的完整编号是{}。",
            "出生证的具体编号是{}。",
            "{}"
        ]
    }
}

household_queries_responses = {
    '姓名': {
        'queries': [
            "这张户口本上的姓名是什么？",
            "能告诉我户口本上的姓名吗？",
            "户口本上的人叫什么名字？",
            "请提取户口本上的姓名。",
            "户口本上的名字是什么？",
            "能帮我确认一下户口本上的姓名吗？",
            "户口本上的全名是什么？",
            "户口本上的人的完整姓名是什么？",
            "请核对一下户口本上的姓名。"
        ],
        'responses': [
            "户口本上的姓名是{}。",
            "户口本上的人叫{}。",
            "户口本上的名字是{}。",
            "户口本上的全名是{}。",
            "户口本上的人的完整姓名是{}。",
            "{}",
        ]
    },
    '出生地': {
        'queries': [
            "这张户口本上的出生地是哪里？",
            "能告诉我户口本上的出生地吗？",
            "户口本上的人在哪里出生的？",
            "请提取户口本上的出生地。",
            "户口本上的出生地是什么地方？",
            "能帮我确认一下户口本上的出生地吗？",
            "户口本上的出生地点是什么？",
            "户口本上的人的出生地是哪里？",
            "请核对一下户口本上的出生地。"
        ],
        'responses': [
            "户口本上的出生地是{}。",
            "户口本上的人在{}出生。",
            "出生地在户口本上是{}。",
            "户口本上的出生地点是{}。",
            "户口本上的人的出生地是{}。",
            "{}"
        ]
    },
    '籍贯': {
        'queries': [
            "这张户口本上的籍贯是哪里？",
            "能告诉我户口本上的籍贯吗？",
            "户口本上的人的籍贯是什么？",
            "请提取户口本上的籍贯。",
            "户口本上的籍贯是什么地方？",
            "能帮我确认一下户口本上的籍贯吗？",
            "户口本上的籍贯是什么？",
            "户口本上的人的籍贯是哪里？",
            "请核对一下户口本上的籍贯。"
        ],
        'responses': [
            "户口本上的籍贯是{}。",
            "户口本上的人的籍贯是{}。",
            "籍贯在户口本上是{}。",
            "{}"
        ]
    },
    '身份证号码': {
        'queries': [
            "这张户口本上的身份证号码是多少？",
            "能告诉我户口本上的身份证号码吗？",
            "户口本上的人的身份证号码是什么？",
            "请提取户口本上的身份证号码。",
            "户口本上的身份证号是多少？",
            "能帮我确认一下户口本上的身份证号码吗？",
            "户口本上的完整身份证号码是什么？",
            "户口本上的人的身份证号码是多少位？",
            "请核对一下户口本上的身份证号码。"
        ],
        'responses': [
            "户口本上的身份证号码是{}。",
            "户口本上的人的身份证号码是{}。",
            "户口本上的身份证号是{}。",
            "身份证号码在户口本上是{}。",
            "户口本上的完整身份证号码是{}。",
            "户口本上的人的身份证号码是18位，具体号码是{}。",
            "{}"
        ]
    },
    '户主关系': {
        'queries': [
            "这张户口本上的户主关系是什么？",
            "能告诉我户口本上的户主关系吗？",
            "户口本上的人与户主的关系是什么？",
            "请提取户口本上的户主关系。",
            "户口本上的户主关系是什么？",
            "户主关系写在户口本上是怎样的？",
            "能帮我确认一下户口本上的户主关系吗？",
            "户口本上的人与户主的关系是？",
            "请核对一下户口本上的户主关系。"
        ],
        'responses': [
            "户口本上的户主关系是{}。",
            "户口本上的人与户主的关系是{}。",
            "户主关系在户口本上是{}。",
            "{}"
        ]
    },
    '性别': {
        'queries': [
            "这张户口本上的性别是什么？",
            "能告诉我户口本上的性别吗？",
            "户口本上的人的性别是什么？",
            "请提取户口本上的性别。",
            "户口本上的性别是什么？",
            "性别写在户口本上是怎样的？",
            "能帮我确认一下户口本上的性别吗？",
            "户口本上的性别是男还是女？",
            "户口本上的人是男性还是女性？",
            "请核对一下户口本上的性别。"
        ],
        'responses': [
            "户口本上的性别是{}。",
            "户口本上的人的性别是{}。",
            "性别在户口本上是{}。",
            "户口本上的人是{}。",
            "{}"
        ]
    },
    '民族': {
        'queries': [
            "这张户口本上的民族是什么？",
            "能告诉我户口本上的民族吗？",
            "户口本上的人的民族是什么？",
            "请提取户口本上的民族。",
            "户口本上的民族是什么？",
            "能帮我确认一下户口本上的民族吗？",
            "户口本上的人属于哪个民族？",
            "请核对一下户口本上的民族。"
        ],
        'responses': [
            "户口本上的民族是{}。",
            "户口本上的人的民族是{}。",
            "民族在户口本上是{}。",
            "{}",
        ]
    },
    '出生日期': {
        'queries': [
            "这张户口本上的出生日期是哪一天？",
            "能告诉我户口本上的出生日期吗？",
            "户口本上的人的出生日期是什么？",
            "请提取户口本上的出生日期。",
            "户口本上的出生日期是哪天？",
            "出生日期写在户口本上是怎样的？",
            "能帮我确认一下户口本上的出生日期吗？",
            "户口本上的出生日期是什么时候？",
            "户口本上的人是哪一年出生的？",
            "请核对一下户口本上的出生日期。"
        ],
        'responses': [
            "户口本上的出生日期是{}。",
            "户口本上的人的出生日期是{}。",
            "出生日期在户口本上是{}。",
            "户口本上的人是{}出生的。",
            "{}"
        ]
    }
}

idcard_queries_responses = {
    '姓名': {
        'queries': [
            "这张身份证上的姓名是什么？",
            "能告诉我身份证上的姓名吗？",
            "身份证上的人叫什么名字？",
            "请提取身份证上的姓名。",
            "身份证上的名字是什么？",
            "能帮我确认一下身份证上的姓名吗？",
            "身份证上的全名是什么？",
            "身份证上的人的完整姓名是什么？",
            "请核对一下身份证上的姓名。"
        ],
        'responses': [
            "身份证上的姓名是{}。",
            "身份证上的人叫{}。",
            "身份证上的名字是{}。",
            "身份证上的全名是{}。",
            "身份证上的人的完整姓名是{}。",
            "身份证上的姓名是{}。",
            "{}"
        ]
    },
    '身份证号码': {
        'queries': [
            "这张身份证上的身份证号码是多少？",
            "能告诉我身份证上的身份证号码吗？",
            "身份证上的人的身份证号码是什么？",
            "请提取身份证上的身份证号码。",
            "身份证上的身份证号是多少？",
            "能帮我确认一下身份证上的身份证号码吗？",
            "身份证上的完整身份证号码是什么？",
            "身份证上的人的身份证号码是多少位？",
            "请核对一下身份证上的身份证号码。"
        ],
        'responses': [
            "身份证上的身份证号码是{}。",
            "身份证上的人的身份证号码是{}。",
            "身份证上的身份证号是{}。",
            "身份证号码在身份证上是{}。",
            "身份证上的完整身份证号码是{}。",
            "身份证上的人的身份证号码是18位，具体号码是{}。",
            "{}"
        ]
    },
    '地址': {
        'queries': [
            "这张身份证上的地址是哪里？",
            "能告诉我身份证上的地址吗？",
            "身份证上的人的地址是什么？",
            "请提取身份证上的地址。",
            "身份证上的地址是什么地方？",
            "能帮我确认一下身份证上的地址吗？",
            "身份证上的详细地址是什么？",
            "身份证上的人的住址是哪里？",
            "请核对一下身份证上的地址。"
        ],
        'responses': [
            "身份证上的地址是{}。",
            "身份证上的人的地址是{}。",
            "身份证上的详细地址是{}。",
            "身份证上的人的住址是{}。",
            "{}"
        ]
    }
}

def get_query_response(input_type, value, ftype='出生证'):
    if ftype == '出生证':
        queries_responses = birthcer_queries_responses
    elif ftype == '户口本':
        queries_responses = household_queries_responses
    elif ftype == '身份证':
        queries_responses = idcard_queries_responses

    if input_type in queries_responses:
        query = random.choice(queries_responses[input_type]['queries'])
        response = random.choice(queries_responses[input_type]['responses']).format(value)
        return query, response
    else:
        raise ValueError(f"未知的字段类型: {input_type}")


def main():
    # 示例使用
    新生儿姓名 = '张三'
    # query, response = get_query_response('新生儿姓名', 新生儿姓名)
    query, response = get_query_response('姓名', 新生儿姓名, ftype='户口本')
    print(query)  # 输出随机的一个查询
    print(response)  # 输出格式化后的响应


if __name__=='__main__':
    main()
